==> openocd_0.5.0.orig.tar.bz2: openocd-0.5.0/src/jtag/drivers/OpenULINK/src/delay.c <==
/***************************************************************************
 *   Copyright (C) 2011 by Martin Schmoelzer                               *
 *   <martin.schmoelzer@student.tuwien.ac.at>                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "delay.h"

void delay_5us(void)
{
  NOP;
}

void delay_1ms(void) {
  u16 i;

  for (i = 0; i < 598; i++);
}

void delay_us(u16 delay)
{
  u16 i;
  u16 maxcount = (delay / 5);

  for (i = 0; i < maxcount; i++) {
    delay_5us();
  }
}

void delay_ms(u16 delay)
{
  u16 i;

  for (i = 0; i < delay; i++) {
    delay_1ms();
  }
}

==> openocd_0.10.0.orig.tar.bz2: openocd-0.10.0/src/jtag/drivers/OpenULINK/src/delay.c <==
/***************************************************************************
 *   Copyright (C) 2011 by Martin Schmoelzer                               *
 *   <martin.schmoelzer@student.tuwien.ac.at>                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#include "delay.h"

void delay_5us(void)
{
	NOP;
}

void delay_1ms(void)
{
	uint16_t i;

	for (i = 0; i < 598; i++)
		;
}

void delay_us(uint16_t delay)
{
	uint16_t i;
	uint16_t maxcount = (delay / 5);

	for (i = 0; i < maxcount; i++)
		delay_5us();
}

void delay_ms(uint16_t delay)
{
	uint16_t i;

	for (i = 0; i < delay; i++)
		delay_1ms();
}
